@@ -94,8 +94,8 @@ const char *verbatim_begin	= "<pre>";
 const char *verbatim_end	= "</pre>";
 const char *reserved_begin	= "<strong class='reserved'>";
 const char *reserved_end	= "</strong>";
-const char *position_begin	= "<em class='position'>";
-const char *position_end	= "</em>";
+const char *position_begin	= "<input type='text' readonly onfocus='this.select();'";
+const char *position_end	= " />";
 const char *warned_line_begin	= "<em class='warned'>";
 const char *warned_line_end	= "</em>";
 const char *current_line_begin	= "<span class='curline'>";
