@@ -30,8 +30,6 @@
 #ifndef	_COMPAT_H_
 #define	_COMPAT_H_
 
-/** @file */
-
 #include <sys/types.h>
 
 #if (defined(_WIN32) && !defined(__CYGWIN__)) || defined(__DJGPP__)
@@ -52,10 +50,10 @@ typedef unsigned short	u_short;
 #define	SIG_UNBLOCK	2
 #define	SIG_SETMASK	3
 
-static int __sigtemp;		/**< For the use of #sigprocmask */
+static int __sigtemp;		/**< For the use of sigprocmask */
 
-/** @remark
- *	Repeated test of @CODE{oset != NULL} is to avoid @CODE{"*0"}.
+/*
+ *	Repeated test of oset != NULL is to avoid "*0".
  */
 #define	sigprocmask(how, set, oset)					\
 	((__sigtemp =							\
@@ -69,13 +67,12 @@ static int __sigtemp;		/**< For the use of #sigprocmask */
 		sigsetmask(__sigtemp)), 0)
 #endif
 
-/**
- * @name BYTE_ORDER
- * @details
+/*
+ * BYTE_ORDER
+ *
  * If your system doesn't have an include file with the appropriate
  * byte order set, make sure you specify the correct one.
  */
-/** @{ */
 #ifndef BYTE_ORDER
 #define LITTLE_ENDIAN   1234
 #define BIG_ENDIAN      4321
@@ -85,9 +82,8 @@ static int __sigtemp;		/**< For the use of #sigprocmask */
 #define BYTE_ORDER LITTLE_ENDIAN
 #endif
 #endif
-/** @} */
 
-/** @name Compatibility macros */
+/* Compatibility macros */
 /*
  * Old definitions were rewritten using 'HAVE_XXX' macros.
  *
@@ -106,7 +102,6 @@ static int __sigtemp;		/**< For the use of #sigprocmask */
  * #define	memmove(a, b, n)	bcopy(b, a, n)
  * #endif
 */
-/** @{ */
 #if !defined (HAVE_INDEX) && defined (HAVE_STRCHR)
 #define	index(a, b)		strchr(a, b)
 #endif
@@ -135,79 +130,70 @@ static int __sigtemp;		/**< For the use of #sigprocmask */
 #if !defined (HAVE_MEMMOVE) && defined (HAVE_BCOPY)
 #define	memmove(a, b, n)	bcopy(b, a, n)
 #endif
-/** @} */
 
-/**
- * @def O_ACCMODE
- * @details
- * 32-bit machine.  The #DB routines are theoretically independent of
- * the size of @NAME{u_shorts} and @NAME{u_longs}, but I don't know that anyone has
- * ever actually tried it.  At a minimum, change the following @CODE{\#define}'s
+/*
+ * O_ACCMODE
+ *
+ * 32-bit machine.  The DB routines are theoretically independent of
+ * the size of u_shorts and u_longs, but I don't know that anyone has
+ * ever actually tried it.  At a minimum, change the following #define's
  * if you are trying to compile on a different type of system.
  */
-/** @{ */
-#ifndef O_ACCMODE			/** @NAME{POSIX 1003.1} access mode mask. */
+#ifndef O_ACCMODE			/** POSIX 1003.1 access mode mask. */
 #define	O_ACCMODE	(O_RDONLY|O_WRONLY|O_RDWR)
 #endif
-/** @} */
 
-#ifndef	_POSIX2_RE_DUP_MAX		/** @NAME{POSIX 1003.2} RE limit. */
+#ifndef	_POSIX2_RE_DUP_MAX		/** POSIX 1003.2 RE limit. */
 #define	_POSIX2_RE_DUP_MAX	255
 #endif
 
-/**
- * @details
- * If you can't provide lock values in the @XREF{open,2} call.  Note, this
+/*
+ * If you can't provide lock values in the open(2) call.  Note, this
  * allows races to happen.
  */
-/** @{ */
-#ifndef O_EXLOCK			/** @NAME{4.4BSD} extension. */
+#ifndef O_EXLOCK			/** 4.4BSD extension. */
 #define	O_EXLOCK	0
 #endif
-/** @} */
 
-#ifndef O_SHLOCK			/** @NAME{4.4BSD} extension. */
+#ifndef O_SHLOCK			/** 4.4BSD extension. */
 #define	O_SHLOCK	0
 #endif
 
-#ifndef O_BINARY	/** @NAME{UNIX} systems don't often have or need this */
+#ifndef O_BINARY	/** UNIX systems don't often have or need this */
 #define O_BINARY 0
 #endif
 
-#ifndef O_NONBLOCK	/** @NAME{Win32} systems doesn't have or need this */
+#ifndef O_NONBLOCK	/** Win32 systems doesn't have or need this */
 #define	O_NONBLOCK	0
 #endif
 
-#ifndef EFTYPE		/** @NAME{POSIX 1003.1} format errno. */
+#ifndef EFTYPE		/** POSIX 1003.1 format errno. */
 #define	EFTYPE		EINVAL
 #endif
 
-/** @name POSIX 1003.1 seek values */
-/** @{ */
+/* POSIX 1003.1 seek values */
 #ifndef SEEK_END
 #define	SEEK_SET	0
 #define	SEEK_CUR	1
 #define	SEEK_END	2
 #endif
-/** @} */
 
-#ifndef _POSIX2_RE_DUP_MAX	/** @NAME{POSIX 1003.2} values. */
+#ifndef _POSIX2_RE_DUP_MAX	/** POSIX 1003.2 values. */
 #define	_POSIX2_RE_DUP_MAX	255
 #endif
 
-#ifndef NULL		/** @NAME{ANSI C} @CODE{\#define}s @VAR{NULL} everywhere. */
+#ifndef NULL		/* ANSI C #defines NULL everywhere. */
 #define	NULL		0
 #endif
 
-#ifndef	MAX				/** Usually found in @FILE{\<sys/param.h\>}. */
+#ifndef	MAX				/* Usually found in "<sys/param.h>". */
 #define	MAX(_a,_b)	((_a)<(_b)?(_b):(_a))
 #endif
-#ifndef	MIN				/** Usually found in @FILE{\<sys/param.h\>}. */
+#ifndef	MIN				/* Usually found in "<sys/param.h>". */
 #define	MIN(_a,_b)	((_a)<(_b)?(_a):(_b))
 #endif
 
-/** @name POSIX 1003.1 file type tests. */
-/** @{ */
+/* POSIX 1003.1 file type tests. */
 #ifndef S_ISDIR
 		/** directory */
 #define	S_ISDIR(m)	((m & 0170000) == 0040000)
@@ -220,7 +206,6 @@ static int __sigtemp;		/**< For the use of #sigprocmask */
 		/** fifo */
 #define	S_ISFIFO(m)	((m & 0170000) == 0010000)
 #endif
-/** @} */
 
 #ifndef HAVE_LSTAT
 #define lstat	stat
