@@ -110,6 +110,8 @@ static const char *envname[] = {
 	"GTAGSLIBPATH",
 	"GTAGSLOGGING",
 	/*"GTAGSROOT",*/
+	"GTAGSOBJDIR",
+	"GTAGSOBJDIRPREFIX",
 	"GTAGSTHROUGH",
 	"GTAGS_OPTIONS",
 	"HTAGS_OPTIONS",
